@@ -1,7 +1,7 @@
 /*
  * This file is part of budgie-desktop.
  *
- * Copyright © 2015-2021 Budgie Desktop Developers
+ * Copyright © 2015-2022 Budgie Desktop Developers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -347,7 +347,7 @@ static void budgie_popover_manager_grab(BudgiePopoverManager* self, BudgiePopove
 static void budgie_popover_manager_ungrab(BudgiePopoverManager* self, BudgiePopover* popover) {
 	GdkDisplay* display = NULL;
 
-	if (!self->priv->grabbed || popover != self->priv->active_popover) {
+	if (popover == NULL || !self->priv->grabbed || popover != self->priv->active_popover) {
 		return;
 	}
 
